--
-- WoodLogsWeight
-- Show total weight, volume and number of logs on your truck / trailer.
-- @author:    	kenny456 (kenny456@seznam.cz)
-- @history:	v1.0 - 2017-09-10 - 
-- 
WoodLogsWeight = {};
local WoodLogsWeight_directory = g_currentModDirectory;

function WoodLogsWeight.prerequisitesPresent(specializations)
    return true;
end;

function WoodLogsWeight:load(xmlFile)
	
	self.p = {};
	self.shapeTemp = nil;
	self.weight = 0;
	self.weightDisplay = 0;
	self.weightTemp = 0;
	self.logsCount = 0;
	self.logsCountDisplay = 0;
	self.logsCountTemp = 0;
	self.logsVolume = 0;
	self.logsVolumeDisplay = 0;
	self.logsVolumeTemp = 0;
	self.infoText = "";
	self.infoText2 = "";
	self.infoText3 = "";
	self.shapes = {};
	self.founded = false;
	self.trailer = true;
	self.pointPosZStart = 1.5;
	self.pointPosZEnd = -5.5;
	self.pointPosZStep = 3.5;
	self.hasLogs = true;
	self.finish = false;
	
	for i = 1, table.maxn(self.specializations) do
		local vs = self.specializations[i];
		if vs == SpecializationUtil.getSpecialization("drivable") then
			self.trailer = false;
			for k,joint in pairs(self.attacherJoints) do
				if joint.jointType == Vehicle.JOINTTYPE_SEMITRAILER then
					self.hasLogs = false;
				end;
			end;
			self.pointPosZStart = -0.4;
			self.pointPosZEnd = -3.3;
			self.pointPosZStep = 3;
			--print('truck');
		else
			local vs = self.specializations[i];
			if vs == SpecializationUtil.getSpecialization("foldable") then
					self.pointPosZStart = 4.5;
					self.pointPosZEnd = -3.5;
					self.pointPosZStep = 3;
				end;
			--print('trailer long');
		end;
	end;
	
	self.point = createTransformGroup("point");
	link(self.rootNode, self.point);
	setRotation(self.point, math.rad(0), math.rad(90), math.rad(0));
	setTranslation(self.point, 2.3, 0.9, self.pointPosZStart);
	local iconWidth = math.floor(0.035 * g_screenWidth) / g_screenWidth;
	local iconHeight = iconWidth;
	local x,y = g_currentMission.fuelLevelStatusBarPosX, g_currentMission.fuelLevelStatusBarPosY;
    local w,h = g_currentMission.speedHud.width,g_currentMission.speedHud.height;
    WoodLogsWeight.overlayLogs = Overlay:new("overlayLogs", Utils.getFilename("wood.dds", WoodLogsWeight_directory), x+0.092,y-0.002, iconWidth*0.7,iconHeight);
    WoodLogsWeight.overlayVehicleSchema = Overlay:new("overlayVehicleSchema", Utils.getFilename("vehicleSchema.dds", WoodLogsWeight_directory), x+0.076,y+0.008, iconWidth*0.5,iconHeight*0.8);
    WoodLogsWeight.overlayTrailerSchema = Overlay:new("overlayTrailerSchema", Utils.getFilename("trailerSchema2.dds", WoodLogsWeight_directory), x+0.076,y-0.040, iconWidth*0.7,iconHeight*0.559);
end;

function WoodLogsWeight:delete()
end;

function WoodLogsWeight:readStream(streamId, connection)
end;

function WoodLogsWeight:writeStream(streamId, connection)
end;

function WoodLogsWeight:mouseEvent(posX, posY, isDown, isUp, button)
end;

function WoodLogsWeight:keyEvent(unicode, sym, modifier, isDown)
end;

function WoodLogsWeight:update(dt)
	if self:getIsActive(true) and self.hasLogs == true then
		while self.finish == false do
			local x,y,z = getTranslation(self.point);
			local xW,yW,zW = getWorldTranslation(self.point);
			--drawDebugPoint(xW,yW,zW,1,0.5,1,1);
			if x > -1.6 then
				x = x - 0.2;
			else
				x = 2.1;
				self.finish = true;
				if z > self.pointPosZEnd then
					z = z - self.pointPosZStep;
				else
					z = self.pointPosZStart;
					if y < 3.7 then
						y = y + 0.1;
					else
						y = 0.9;
						if self.logsCountTemp == 0 then
							self.logsCountTemp = self.logsCount;
						end;
						if self.logsCount == self.logsCountTemp then
							self.logsCountDisplay = self.logsCountTemp;
						else
							self.logsCountDisplay = self.logsCount;
						end;
						self.logsVolumeDisplay = self.logsVolume;
						self.weightDisplay = self.weight;
						self.shapes = {};
						self.weight = 0;
						self.logsCount = 0;
						self.logsVolume = 0;
					end;
				end;
			end;
			if self.logsCountTemp == 0 then
				self.logsCountDisplay = self.logsCount;
				self.logsVolumeDisplay = self.logsVolume;
				self.weightDisplay = self.weight;
			end;
			setTranslation(self.point, x,y,z);
			--print(x .. ',' .. y .. ',' .. z);
			if self.point ~= nil then
			local x,y,z = getWorldTranslation(self.point);
			local nx,ny,nz = localDirectionToWorld(self.point, 1,0,0);
			local yx,yy,yz = localDirectionToWorld(self.point, 0,1,0);
			local shape, minY, maxY, minZ, maxZ = findSplitShape(x,y,z, nx,ny,nz, yx,yy,yz, 0.7, 0.7);
			if shape ~= 0 then
				--print('tree found');
				if shapeTemp == nil or shape ~= shapeTemp then
					for _,v in pairs(self.shapes) do
						if v == shape then
							self.founded = true;
							break
						end
					end
					if self.founded == false then
						self.weight = self.weight + getMass(shape);
						self.logsCount = self.logsCount + 1;
						self.logsVolume = self.logsVolume + getVolume(shape);
						shapeTemp = shape;
						table.insert(self.shapes, shape);
					end;
					self.founded = false;
				end;
				self.infoText = "";
				self.infoText = self.infoText .. "Tree-Volume: " .. string.format("%.2f", getVolume(shape)) .. " m3\n";
				self.infoText = self.infoText .. "Tree-Mass: " .. string.format("%.2f", getMass(shape)) .. " t\n";
			end;
			shape = 0;
			end;
			self.infoText3 = "";
			self.infoText3 = self.infoText3 .. string.format("%.2f", y) .. " / " .. string.format("%.2f", z) .. "\n";
		end;
		self.finish = false;
		self.infoText2 = self.infoText2 .. "Logs: " .. --[[self.logsCountDisplay ..]] "\n";
		self.infoText2 = self.infoText2 .. "Weight: " .. --[[string.format("%.2f", self.weightDisplay) .. " t]] "\n";
		self.infoText2 = self.infoText2 .. "Vol.: " .. --[[string.format("%.1f", self.logsVolumeDisplay) .. " m3]] "\n";
	end;
end;

function WoodLogsWeight:updateTick(dt)
end;

function WoodLogsWeight:draw()
	if self:getIsActive(true) then
		if self.logsCountDisplay > 0 then
			WoodLogsWeight.overlayLogs:render();
			if self.trailer == true then
				WoodLogsWeight.overlayTrailerSchema:render();
				self.posY = 0.051;
			else
				WoodLogsWeight.overlayVehicleSchema:render();
				self.posY = 0.002;
			end;
			--renderText(0.9080, g_currentMission.fuelLevelStatusBarPosY + 0.2305, g_currentMission.fillLevelTextSizeSmall, self.infoText);
			--renderText(0.9080, g_currentMission.fuelLevelStatusBarPosY + 0.1105, g_currentMission.fillLevelTextSizeSmall, self.infoText3);
			setTextBold(false);
			setTextAlignment(RenderText.ALIGN_LEFT);
			setTextColor(0.6307, 0.6307, 0.6307, 1);
			renderText(g_currentMission.fuelLevelStatusBarPosX+0.076, g_currentMission.fuelLevelStatusBarPosY - self.posY, g_currentMission.fillLevelTextSizeSmall*0.9, self.infoText2);
			setTextBold(true);
			setTextColor(1, 1, 1, 1);
			renderText(g_currentMission.fuelLevelStatusBarPosX+0.092, g_currentMission.fuelLevelStatusBarPosY - self.posY, g_currentMission.fillLevelTextSizeSmall*0.9, string.format("%.0f", self.logsCountDisplay));
			renderText(g_currentMission.fuelLevelStatusBarPosX+0.097, g_currentMission.fuelLevelStatusBarPosY - self.posY - 0.012, g_currentMission.fillLevelTextSizeSmall*0.9, string.format("%.2f", self.weightDisplay) .. " t");
			renderText(g_currentMission.fuelLevelStatusBarPosX+0.089, g_currentMission.fuelLevelStatusBarPosY - self.posY - 0.023, g_currentMission.fillLevelTextSizeSmall*0.9, string.format("%.1f", self.logsVolumeDisplay) .. "m3");
			setTextBold(false);
			self.infoText2 = "";
		end;
	end;
end;

function WoodLogsWeight:onLeave()
end;